@@ -53,7 +53,7 @@ class OpenAPIFormDataBody(OpenAPIBody):
             nullable=self.nullable or None,
         )
 
-    def get_media_type_object(
+    def get_openapi_media_type(
         self, model_name_map: ModelNameMap, schemas: Schemas
     ) -> openapi_models.MediaType:
         encodings: typing.Dict[str, openapi_models.Encoding] = {}
@@ -67,7 +67,7 @@ class OpenAPIFormDataBody(OpenAPIBody):
             encoding=encodings or None,
         )
 
-    def get_media_type(self) -> str:
+    def get_media_type_string(self) -> str:
         return self.media_type
 
     def get_openapi(
@@ -77,7 +77,7 @@ class OpenAPIFormDataBody(OpenAPIBody):
             description=self.description,
             required=self.required,
             content={
-                self.get_media_type(): self.get_media_type_object(
+                self.get_media_type_string(): self.get_openapi_media_type(
                     model_name_map, schemas
                 )
             },
